# Zgli
All documentation available at [zgli's website](https://zgly-92273.web.app/)

#### 1. Instalation
```pip install zgli```

#### 2. Quick Start
Follow along the [quick start guide](https://zgly-92273.web.app/quickstart.html), and learn the tool using an hands-on approach.

#### 3. Normalized Compression Distance (NCD)
Want to better understand the Normalized compression distance? Read a quick explantation [here](https://zgly-92273.web.app/ncd.html)

#### 4. Dependencies
This tool uses:
* [Numpy](https://numpy.org/)
* [Pandas](https://pandas.pydata.org/)
* [Tqdm](https://tqdm.github.io/)
* [Multiprocessing](https://docs.python.org/3/library/multiprocessing.html)